==> apache-asterixdb-0.9.1-source-release.zip: apache-asterixdb-0.9.1/asterix-active/src/main/java/org/apache/asterix/active/message/ActiveManagerMessage.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.asterix.active.message;

import java.io.Serializable;

import org.apache.asterix.active.ActiveManager;
import org.apache.asterix.common.api.IAppRuntimeContext;
import org.apache.asterix.common.messaging.api.IApplicationMessage;
import org.apache.hyracks.api.exceptions.HyracksDataException;
import org.apache.hyracks.api.service.IControllerService;

public class ActiveManagerMessage implements IApplicationMessage {
    public static final byte STOP_ACTIVITY = 0x00;

    private static final long serialVersionUID = 1L;
    private final byte kind;
    private final String src;
    private final Serializable payload;

    public ActiveManagerMessage(byte kind, String src, Serializable payload) {
        this.kind = kind;
        this.src = src;
        this.payload = payload;
    }

    public Serializable getPayload() {
        return payload;
    }

    public byte getKind() {
        return kind;
    }

    public String getSrc() {
        return src;
    }

    @Override
    public void handle(IControllerService cs) throws HyracksDataException, InterruptedException {
        IAppRuntimeContext appContext = (IAppRuntimeContext) cs.getApplicationContext();
        ((ActiveManager) appContext.getActiveManager()).submit(this);
    }

    @Override
    public String toString() {
        return ActiveManagerMessage.class.getSimpleName();
    }
}

==> apache-asterixdb-0.9.2-source-release.zip: apache-asterixdb-0.9.2/asterix-active/src/main/java/org/apache/asterix/active/message/ActiveManagerMessage.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.asterix.active.message;

import java.io.Serializable;

import org.apache.asterix.active.ActiveManager;
import org.apache.asterix.common.api.INcApplicationContext;
import org.apache.asterix.common.messaging.api.INcAddressedMessage;
import org.apache.hyracks.api.exceptions.HyracksDataException;

public class ActiveManagerMessage implements INcAddressedMessage {
    public static final byte STOP_ACTIVITY = 0x00;
    public static final byte REQUEST_STATS = 0x01;

    private static final long serialVersionUID = 1L;
    private final byte kind;
    private final Serializable payload;

    public ActiveManagerMessage(byte kind, Serializable payload) {
        this.kind = kind;
        this.payload = payload;
    }

    public Serializable getPayload() {
        return payload;
    }

    public byte getKind() {
        return kind;
    }

    @Override
    public void handle(INcApplicationContext appCtx) throws HyracksDataException, InterruptedException {
        ((ActiveManager) appCtx.getActiveManager()).submit(this);
    }

    @Override
    public String toString() {
        return ActiveManagerMessage.class.getSimpleName();
    }
}
